/* automatically generated by rust-bindgen */

pub const SENSORS_ERR_WILDCARDS: ::std::os::raw::c_int = 1;
pub const SENSORS_ERR_NO_ENTRY:  ::std::os::raw::c_int = 2;
pub const SENSORS_ERR_ACCESS_R:  ::std::os::raw::c_int = 3;
pub const SENSORS_ERR_KERNEL:    ::std::os::raw::c_int = 4;
pub const SENSORS_ERR_DIV_ZERO:  ::std::os::raw::c_int = 5;
pub const SENSORS_ERR_CHIP_NAME: ::std::os::raw::c_int = 6;
pub const SENSORS_ERR_BUS_NAME:  ::std::os::raw::c_int = 7;
pub const SENSORS_ERR_PARSE:     ::std::os::raw::c_int = 8;
pub const SENSORS_ERR_ACCESS_W:  ::std::os::raw::c_int = 9;
pub const SENSORS_ERR_IO:        ::std::os::raw::c_int = 10;
pub const SENSORS_ERR_RECURSION: ::std::os::raw::c_int = 11;
extern "C" {
    pub fn sensors_strerror(errnum: ::std::os::raw::c_int) -> *const ::std::os::raw::c_char;
}
extern "C" {
    #[link_name = "\u{1}sensors_parse_error"]
    pub static mut sensors_parse_error:
        ::std::option::Option<
        unsafe extern "C" fn(err: *const ::std::os::raw::c_char, lineno: ::std::os::raw::c_int),
    >;
}
extern "C" {
    #[link_name = "\u{1}sensors_parse_error_wfn"]
    pub static mut sensors_parse_error_wfn:
        ::std::option::Option<
        unsafe extern "C" fn(
            err: *const ::std::os::raw::c_char,
            filename: *const ::std::os::raw::c_char,
            lineno: ::std::os::raw::c_int,
        ),
    >;
}
extern "C" {
    #[link_name = "\u{1}sensors_fatal_error"]
    pub static mut sensors_fatal_error:
        ::std::option::Option<
        unsafe extern "C" fn(
            proc_: *const ::std::os::raw::c_char,
            err: *const ::std::os::raw::c_char,
        ),
    >;
}
